@@ -6,9 +6,9 @@
 
 #include <ctype.h>
 
-SEXP R_unpaste(SEXP s_strings, SEXP s_sep, SEXP s_whitespace,
+SEXP C_unpaste(SEXP s_strings, SEXP s_sep, SEXP s_whitespace,
 	       SEXP s_nfields);
-void R_cnt_flds_str(char **strings, Sint *nstrings, char **sep,
+void C_cnt_flds_str(char **strings, Sint *nstrings, char **sep,
 		    Sint *white_space, Sint *counts);
 
 #endif
